#!/usr/bin/perl

use strict;
use warnings;
use GD;

STDOUT->autoflush(1);

# file names and checks {{{
# image (should be in JPEG format)
my $imgfile = $ARGV[0];
die "$imgfile not a file or not readable"
    unless (-f $imgfile) and (-r $imgfile);

# output file
my $outfile = $ARGV[1];
# }}}

print "Loading image $imgfile ... "; # {{{
my $image = GD::Image->newFromPng($imgfile, 0);
print "done\n";
# reduce colors if TrueColor
if ($image->isTrueColor) {
    print 'Reducing colors ... ';
    $image->trueColorToPalette(0, 256);
    print "done\n";
}
# }}}

my $insignificant_color;

die "Image too small" if ($image->width<10) or ($image->height<10);

FIND_INSIGNIFICANT: {
    my %colors;
    foreach my $x (0..9) {
        foreach my $y (0..9) {
            my $pal_index = $image->getPixel($x, $y);
            if (defined $colors{$pal_index}) {
                $colors{$pal_index}++;
            } else {
                $colors{$pal_index} = 1;
            }
        }
    }
    my $max = 0;
    foreach (keys %colors) {
        if ($max < $colors{$_}) {
            $insignificant_color = $_;
            $max = $colors{$_};
        }
    }
}
print "Insignificant color: $insignificant_color\n";

my $count = 0;
open (OUT, '>', $outfile) or die "Cannot open $outfile:\n$!";
foreach my $y (0..($image->height - 1)) {
    foreach my $x (0..($image->width - 1)) {
        if ($image->getPixel($x, $y) != $insignificant_color) {
            #print $image->getPixel($x, $y) ."\n";
            printf OUT "%4d, %4d, 0rG Object %d\n", $x, $y, $count;
            ++$count;
        }
    }
}
close(OUT);
print "Found $count interesting spots\n";

exit 0;
# vim: foldmethod=marker
